[Pkg-libvirt-commits] [libguestfs] 78/266: p2v: Call the remote libvirt XML file 'guest.xml'.

Hilko Bengen bengen at moszumanska.debian.org
Fri Oct 3 14:41:44 UTC 2014


This is an automated email from the git hooks/post-receive script.

bengen pushed a commit to annotated tag debian/1%1.27.35-1
in repository libguestfs.

commit 67da00d540fbb8c463e9496864b243d780340d9a
Author: Richard W.M. Jones <rjones at redhat.com>
Date:   Tue Aug 12 12:40:58 2014 +0100

    p2v: Call the remote libvirt XML file 'guest.xml'.
    
    Previously it was called 'libvirt.conf' which is more than a little
    bit confusing.
    
    This is only an internal name, so there is no visible change in
    functionality.
---
 p2v/conversion.c | 2 +-
 p2v/ssh.c        | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/p2v/conversion.c b/p2v/conversion.c
index d2b6c44..f3674c2 100644
--- a/p2v/conversion.c
+++ b/p2v/conversion.c
@@ -205,7 +205,7 @@ start_conversion (struct config *config,
                    " -i libvirtxml"
                    " -o local -os /tmp" /* XXX */
                    " --root first"
-                   " %s/libvirt.conf"
+                   " %s/guest.xml"
                    " </dev/null" /* stdin */
                    " 2>&1"       /* output */
                    " ;"
diff --git a/p2v/ssh.c b/p2v/ssh.c
index ff906df..993beb4 100644
--- a/p2v/ssh.c
+++ b/p2v/ssh.c
@@ -619,9 +619,9 @@ start_remote_connection (struct config *config,
   if (wait_for_prompt (h) == -1)
     goto error;
 
   /* Upload the libvirt configuration file to the remote directory. */
   if (mexp_printf (h,
-                   "cat > '%s/libvirt.conf' << '__%s__'\n"
+                   "cat > '%s/guest.xml' << '__%s__'\n"
                    "%s"
                    "__%s__\n",
                    remote_dir, magic,
@@ -619,9 +619,9 @@ start_remote_connection (struct config *config,
     goto error;
 
-  /* Upload the libvirt configuration file to the remote directory. */
+  /* Upload the guest libvirt XML to the remote directory. */
   if (mexp_printf (h,

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-libvirt/libguestfs.git



More information about the Pkg-libvirt-commits mailing list